@@ -8,19 +8,18 @@ package Tk::Entry;
 #
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994 Sun Microsystems, Inc.
-# Copyright (c) 1995-1999 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-2003 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 
 use vars qw($VERSION);
-$VERSION = '3.033'; # $Id: //depot/Tk8/Entry/Entry.pm#33 $
+$VERSION = '3.042'; # $Id: //depot/Tk8/Entry/Entry.pm#42 $
 
 # modify it under the same terms as Perl itself, subject
 # to additional disclaimer in license.terms due to partial
 # derivation from Tk4.0 sources.
 
-require Tk::Widget;
-require Tk::Clipboard;
-
+use Tk::Widget ();
+use Tk::Clipboard ();
 use base  qw(Tk::Clipboard Tk::Widget);
 
 import Tk qw(Ev $XS_VERSION);
@@ -32,7 +31,7 @@ bootstrap Tk::Entry;
 sub Tk_cmd { \&Tk::entry }
 
 Tk::Methods('bbox','delete','get','icursor','index','insert','scan',
-            'selection','xview');
+            'selection','validate','xview');
 
 use Tk::Submethods ( 'selection' => [qw(clear range adjust present to from)],
 		     'xview'     => [qw(moveto scroll)],
@@ -284,6 +283,7 @@ sub MouseSelect
  return unless defined $cur;
  my $anchor = $w->index('anchor');
  return unless defined $anchor;
+ $Tk::pressX ||= $x;
  if (($cur != $anchor) || (abs($Tk::pressX - $x) >= 3))
   {
    $Tk::mouseMoved = 1
@@ -504,6 +504,8 @@ sub getSelected
  my $w = shift;
  return undef unless $w->selectionPresent;
  my $str = $w->get;
+ my $show = $w->cget('-show');
+ $str = $show x length($str) if (defined $show);
  my $s = $w->index('sel.first');
  my $e = $w->index('sel.last');
  return substr($str,$s,$e+1-$s);
