@@ -1,7 +1,7 @@
 package Tk::Animation;
 
 use vars qw($VERSION);
-$VERSION = '3.016'; # $Id: //depot/Tk8/Tk/Animation.pm#16 $
+$VERSION = '3.020'; # $Id: //depot/Tk8/Tk/Animation.pm#20 $
 
 use Tk::Photo;
 use base  qw(Tk::Photo);
@@ -53,6 +53,7 @@ sub set_image
  my $frames = $obj->{'_frames_'};
  return unless $frames && @$frames;
  $index = 0 unless $index < @$frames;
+ $obj->blank if 0;  # helps some make others worse
  $obj->copy($frames->[$index]);
  $obj->{'_frame_index_'} = $index;
 }
@@ -71,13 +72,15 @@ sub start_animation
  my $frames = $obj->{'_frames_'};
  return unless $frames && @$frames;
  my $w = $obj->MainWindow;
- $obj->RepeatId($w->repeat($period,[$obj,'next_image']));
+ $obj->stop_animation;
+ $obj->{'_NextId_'} = $w->repeat($period,[$obj,'next_image']);
 }
 
 sub stop_animation
 {
  my ($obj) = @_;
- $obj->CancelRepeat;
+ my $id = delete $obj->{'_NextId_'};
+ Tk::catch { $id->cancel } if $id;
  $obj->set_image(0);
 }
 
