@@ -1,4 +1,4 @@
-# Copyright (c) 1995-1999 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-2003 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Image;
@@ -10,7 +10,7 @@ require DynaLoader;
 use base qw(DynaLoader Tk); # but are they ?
 
 use vars qw($VERSION);
-$VERSION = '3.009'; # $Id: //depot/Tk8/Tk/Image.pm#9 $
+$VERSION = '3.016'; # $Id: //depot/Tk8/Tk/Image.pm#16 $
 
 sub new
 {
@@ -18,7 +18,7 @@ sub new
  my $widget  = shift;
  $package->InitClass($widget);
  my $leaf = $package->Tk_image;
- my $obj = $widget->image('create',$leaf,@_);
+ my $obj = $widget->Tk::image('create',$leaf,@_);
  return bless $obj,$package;
 }
 
@@ -55,6 +55,10 @@ sub Construct
 {
  my ($base,$name) = @_;
  my $class = (caller(0))[0];
+
+ # Hack for broken ->isa in perl5.6.0
+ delete ${"$class\::"}{'::ISA::CACHE::'} if $] == 5.006;
+
  *{"Tk::Widget::$name"}  = sub { $class->new(@_) };
 }
 
