@@ -1,14 +1,14 @@
-# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-2003 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::MMtry;
 use Config;
 require Exporter;
 
-use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '3.005'; # $Id: //depot/Tk8/Tk/MMtry.pm#5$
+use vars qw($VERSION @EXPORT);
+$VERSION = '3.012'; # $Id: //depot/Tk8/Tk/MMtry.pm#12 $
 
-@ISA = qw(Exporter);
+use base  qw(Exporter);
 @EXPORT = qw(try_compile try_run);
 use strict;
 use File::Basename;
