@@ -17,10 +17,11 @@ require Tk;
 require Tk::Widget;
 require Tk::Wm;
 require Tk::Derived;
+require Tk::Menu::Item;
 
 
 use vars qw($VERSION);
-$VERSION = '3.043'; # $Id: //depot/Tk8/Tk/Menu.pm#43 $
+$VERSION = '3.048'; # $Id: //depot/Tk8/Tk/Menu.pm#48 $
 
 use strict;
 
@@ -57,6 +58,7 @@ sub InitObject
  my ($menu,$args) = @_;
  my $menuitems = delete $args->{-menuitems};
  $menu->SUPER::InitObject($args);
+ $menu->ConfigSpecs(-foreground => ['SELF']);
  if (defined $menuitems)
   {
    # If any other args do configure now
@@ -71,7 +73,6 @@ sub InitObject
 
 sub AddItems
 {
- require Tk::Menu::Item;
  my $menu = shift;
  ITEM:
  while (@_)
@@ -693,7 +694,7 @@ sub NextEntry
   }
  $menu->activate($i);
  $menu->GenerateMenuSelect;
- if ($menu->type($i) eq 'cascade')
+ if ($menu->cget('-type') eq 'menubar' && $menu->type($i) eq 'cascade')
   {
    my $cascade = $menu->entrycget($i, '-menu');
    $menu->postcascade($i);
