@@ -1,15 +1,15 @@
-# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-2003 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Message;
 use strict;
 
-use vars qw($VERSION @ISA);
-$VERSION = '3.005'; # $Id: //depot/Tk8/Tk/Message.pm#5$
+use vars qw($VERSION);
+$VERSION = '3.012'; # $Id: //depot/Tk8/Tk/Message.pm#12 $
 
 require Tk::Widget;
 
-@ISA = qw(Tk::Widget);
+use base  qw(Tk::Widget);
 
 Construct Tk::Widget 'Message';
 
