@@ -93,8 +93,12 @@ Tcl_SetChannelOption(Tcl_Interp *interp, Tcl_Channel chan,
   {
    if (strcmp(newValue,"binary") == 0)
     {
-#if defined(WIN32) || defined(__EMX__)
+#ifdef USE_PERLIO
+     PerlIO_binmode(aTHX_ f, '<', O_BINARY, Nullch);
+#else
+#if defined(WIN32) || defined(__EMX__)  || defined(__CYGWIN__)
      setmode(PerlIO_fileno(f), O_BINARY);
+#endif
 #endif
      return TCL_OK;
     }
