@@ -1,5 +1,7 @@
 # Gedi master advanced text editor.
 
+use Tk::TextEdit;
+
 use vars qw/$TOP/;
 
 my $TOP;
@@ -91,7 +93,7 @@ sub Gedi {
         -iconname         => 'GEDI',
     );
 
-
+$TOP->withdraw;
 
 $text_frame = $TOP->Frame->pack
 	(-anchor=>'nw', expand=>'yes', -fill => 'both'); # autosizing
@@ -104,7 +106,7 @@ $textwindow = $text_frame->Scrolled(
 	# once window shrinks below height
 	# and the line counters go off the screen.
 	# seems to be a problem with the Tk::pack command;
-	height => 40, 	 
+#	height => 40, 	 
 	-background => 'white',
 	-wrap=> 'none', 
 	-setgrid => 'true', # use this for autosizing
@@ -158,6 +160,15 @@ $textwindow->ResetUndo;
 
 $textwindow->CallNextGUICallback;
 
+# adjust height
+$TOP->update;
+my $menuheight = ($TOP->wrapper)[1];
+my $TOPheight = 30 + $TOP->reqheight + $menuheight;
+if ($TOP->screenheight < $TOPheight) {
+    $textwindow->GeometryRequest($textwindow->reqwidth, $textwindow->reqheight - ($TOPheight - $TOP->screenheight));
+}
+$TOP->deiconify;
+
 }
 
 
