@@ -331,7 +331,7 @@ Tcl_NewListObj (int objc, Tcl_Obj *CONST objv[])
         */
        if (SvREFCNT(sv) <= 0 || SvTEMP(sv))
         {
-         LangDebug(__FUNCTION__ " %d:\n",objc);
+         LangDebug("%s %d:\n",__FUNCTION__, objc);
          sv_dump(sv);
         }
        av_store(av,objc,sv);
@@ -873,7 +873,7 @@ void
 Tcl_DStringSetLength(Tcl_DString *svp,int len)
 {
  SV *sv = DStringSV(svp);
- char *s = SvGROW(sv,len+1);
+ char *s = SvGROW(sv,(Size_t)(len+1));
  s[len] = '\0';
  SvCUR(sv) = len;
 }
