@@ -533,7 +533,7 @@ Tk_CanvasDashPrintProc(clientData, tkwin, widgRec, offset, freeProcPtr)
     Arg result = NULL;
 
     if (i<0) {
-	p = (-i > sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
+	p = (-i > (int) sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
         result = Tcl_NewStringObj(p,-i);
 	return result;
     } else if (!i) {
@@ -542,7 +542,7 @@ Tk_CanvasDashPrintProc(clientData, tkwin, widgRec, offset, freeProcPtr)
 	return result;
     }
     result = Tcl_NewListObj(0,NULL);
-    p = (i > sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
+    p = (i > (int) sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
     while(i--) {
 	Tcl_ListObjAppendElement(NULL,result,Tcl_NewIntObj(*p++ & 0xff));
     }
@@ -789,7 +789,7 @@ Tk_GetDash(interp, ovalue, dash)
 	} else {
 	    goto badDashList;
 	}
-	if (i > sizeof(char *)) {
+	if (i > (int) sizeof(char *)) {
 	    dash->pattern.pt = pt = (char *) ckalloc(strlen(value));
 	} else {
 	    pt = dash->pattern.array;
@@ -813,7 +813,7 @@ Tk_GetDash(interp, ovalue, dash)
     if (ABS(dash->number) > sizeof(char *)) {
 	ckfree((char *) dash->pattern.pt);
     }
-    if ( argc > sizeof(char *)) {
+    if ( argc > (int) sizeof(char *)) {
 	dash->pattern.pt = pt = (char *) ckalloc(argc);
     } else {
 	pt = dash->pattern.array;
@@ -1161,7 +1161,7 @@ Tk_Outline *outline;
 	char *q;
 	int i = -dash->number;
 
-        p = (i > sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
+        p = (i > (int) sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
 	q = (char *) ckalloc(2*i);
 	i = DashConvert(q, p, i, width);
 	XSetDashes(((TkCanvas *)canvas)->display, outline->gc, outline->offset, q, i);
@@ -1169,7 +1169,7 @@ Tk_Outline *outline;
 	ckfree(q);
     } else if ( dash->number>2 || (dash->number==2 &&
 		(dash->pattern.array[0]!=dash->pattern.array[1]))) {
-        p = (char *) (dash->number > sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
+        p = (char *) (dash->number > (int) sizeof(char *)) ? dash->pattern.pt : dash->pattern.array;
 	XSetDashes(((TkCanvas *)canvas)->display, outline->gc, outline->offset, p, dash->number);
         values.line_style = LineOnOffDash;
     } else {
