@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkTextIndex.c 1.15 97/06/17 17:49:24
+ * RCS: @(#) $Id: tkTextIndex.c,v 1.2 1998/09/14 18:23:19 stanton Exp $
  */
 
 #include "default.h"
@@ -212,6 +212,8 @@ TkTextGetIndex(interp, textPtr, string, indexPtr)
     int wantLast, result;
     char c;
 
+    if (*string == 0) goto error;
+
     /*
      *---------------------------------------------------------------------
      * Stage 1: check to see if the index consists of nothing but a mark
